<?php
namespace Bushelpowered\Api\Grain\Contracts\V1\Model;
        
class PricingHistoryStandard implements \Bushelpowered\Api\Common\Event\StandardRecord, \Bushelpowered\Api\Common\HasSourceTimestamps, \Bushelpowered\Api\Common\HasTimestamps
{
    /** @var string $id The primary unique identifier.*/
    public string $id;
    /** @var string $entityRevisionId The revision idempotency key.*/
    public string $entityRevisionId;
    /** @var string $tenantId The tenant identifier.*/
    public string $tenantId;
    /** @var string $datasourceId The datasource identifier.*/
    public string $datasourceId;
    /** @var string $integrationId The global unique identifier of the source record, often concatenation of the datasource and source identifiers to ensure uniqueness.*/
    public string $integrationId;
    /** @var string $sourceId The source record identifier.*/
    public string $sourceId;
    /** @var null|string $sourcePricingLineId The source pricing line identifier.*/
    public ?string $sourcePricingLineId = null;
    /** @var null|string $pricingLineId The pricing line identifier.*/
    public ?string $pricingLineId = null;
    /** @var null|string $sourceType A name or reason for the pricing event, such as freight charge or tax.*/
    public ?string $sourceType = null;
    /** @var null|float $sourcePrice The monetary effect of this event.*/
    public ?float $sourcePrice = null;
    /** @var null|string $sourcePricingMode The modality by which pricing is affected, primarily flat or per-unit.*/
    public ?string $sourcePricingMode = null;
    /** @var null|string $accountId The bushel id of the account that owns this record, if any.*/
    public ?string $accountId = null;
    /** @var null|string $locationId The bushel id of the location that owns this record, if any.*/
    public ?string $locationId = null;
    /** @var string $updatedAt The last time this record was updated. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00*/
    public string $updatedAt;
    /** @var string $createdAt When the record was created. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00*/
    public string $createdAt;
    /** @var null|string $deletedAt The time the record was deleted. Null if not deleted. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00*/
    public ?string $deletedAt = null;
    /** @var string $sourceCreatedAt Created date-time from data source. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00*/
    public string $sourceCreatedAt;
    /** @var string $sourceUpdatedAt Updated date-time from data source. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00*/
    public string $sourceUpdatedAt;
    /** @var null|string $sourceDeletedAt Deleted date-time from data source. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00*/
    public ?string $sourceDeletedAt = null;

    /**
     * @param  string  $id The primary unique identifier.
     * @param  string  $entityRevisionId The revision idempotency key.
     * @param  string  $tenantId The tenant identifier.
     * @param  string  $datasourceId The datasource identifier.
     * @param  string  $integrationId The global unique identifier of the source record, often concatenation of the datasource and source identifiers to ensure uniqueness.
     * @param  string  $sourceId The source record identifier.
     * @param  null|string  $sourcePricingLineId The source pricing line identifier.
     * @param  null|string  $pricingLineId The pricing line identifier.
     * @param  null|string  $sourceType A name or reason for the pricing event, such as freight charge or tax.
     * @param  null|float  $sourcePrice The monetary effect of this event.
     * @param  null|string  $sourcePricingMode The modality by which pricing is affected, primarily flat or per-unit.
     * @param  null|string  $accountId The bushel id of the account that owns this record, if any.
     * @param  null|string  $locationId The bushel id of the location that owns this record, if any.
     * @param  string  $updatedAt The last time this record was updated. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     * @param  string  $createdAt When the record was created. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     * @param  null|string  $deletedAt The time the record was deleted. Null if not deleted. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     * @param  string  $sourceCreatedAt Created date-time from data source. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     * @param  string  $sourceUpdatedAt Updated date-time from data source. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     * @param  null|string  $sourceDeletedAt Deleted date-time from data source. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     */
    public function __construct(string $id, string $entityRevisionId, string $tenantId, string $datasourceId, string $integrationId, string $sourceId, ?string $sourcePricingLineId, ?string $pricingLineId, ?string $sourceType, ?float $sourcePrice, ?string $sourcePricingMode, ?string $accountId, ?string $locationId, string $updatedAt, string $createdAt, ?string $deletedAt, string $sourceCreatedAt, string $sourceUpdatedAt, ?string $sourceDeletedAt)
    {
        $this->id = $id;
        $this->entityRevisionId = $entityRevisionId;
        $this->tenantId = $tenantId;
        $this->datasourceId = $datasourceId;
        $this->integrationId = $integrationId;
        $this->sourceId = $sourceId;
        $this->sourcePricingLineId = $sourcePricingLineId;
        $this->pricingLineId = $pricingLineId;
        $this->sourceType = $sourceType;
        $this->sourcePrice = $sourcePrice;
        $this->sourcePricingMode = $sourcePricingMode;
        $this->accountId = $accountId;
        $this->locationId = $locationId;
        $this->updatedAt = $updatedAt;
        $this->createdAt = $createdAt;
        $this->deletedAt = $deletedAt;
        $this->sourceCreatedAt = $sourceCreatedAt;
        $this->sourceUpdatedAt = $sourceUpdatedAt;
        $this->sourceDeletedAt = $sourceDeletedAt;
    }
    
    /**
     * @return string The primary unique identifier.
     */
    public function getId(): string
    {
        return $this->id;
    }
    /**
     * @return string The tenant identifier.
     */
    public function getTenantId(): string
    {
        return $this->tenantId;
    }
    /**
     * @return string The datasource identifier.
     */
    public function getDatasourceId(): string
    {
        return $this->datasourceId;
    }
    /**
     * @return string The global unique identifier of the source record, often concatenation of the datasource and source identifiers to ensure uniqueness.
     */
    public function getIntegrationId(): string
    {
        return $this->integrationId;
    }
    /**
     * @return string The source record identifier.
     */
    public function getSourceId(): string
    {
        return $this->sourceId;
    }
    /**
     * @return null|string The bushel id of the account that owns this record, if any.
     */
    public function getAccountId(): ?string
    {
        return $this->accountId;
    }
    /**
     * @return null|string The bushel id of the location that owns this record, if any.
     */
    public function getLocationId(): ?string
    {
        return $this->locationId;
    }
    /**
     * @return string The last time this record was updated. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     */
    public function getUpdatedAt(): string
    {
        return $this->updatedAt;
    }
    /**
     * @return string When the record was created. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     */
    public function getCreatedAt(): string
    {
        return $this->createdAt;
    }
    /**
     * @return null|string The time the record was deleted. Null if not deleted. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     */
    public function getDeletedAt(): ?string
    {
        return $this->deletedAt;
    }
    /**
     * @return string Created date-time from data source. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     */
    public function getSourceCreatedAt(): string
    {
        return $this->sourceCreatedAt;
    }
    /**
     * @return string Updated date-time from data source. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     */
    public function getSourceUpdatedAt(): string
    {
        return $this->sourceUpdatedAt;
    }
    /**
     * @return null|string Deleted date-time from data source. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     */
    public function getSourceDeletedAt(): ?string
    {
        return $this->sourceDeletedAt;
    }
}