<?php
namespace Bushelpowered\Api\Trade\Futures\V1\Model;
        
class BidDetailStandard 
{
    /** @var string $locationName The centre name for the Location*/
    public string $locationName;
    /** @var string $commodityName The Commodity's name*/
    public string $commodityName;
    /** @var string $productId The Product's id in the futures database.*/
    public string $productId;
    /** @var string $productName The Product's name.*/
    public string $productName;
    /** @var string $pricingType The Product's Type.*/
    public string $pricingType;
    /** @var string $tickSize The Tick Size overwritten by the merchandiser.*/
    public string $tickSize;
    /** @var string $marketTickSize The default Tick Size for the commodity.*/
    public string $marketTickSize;
    /** @var string $bidId The bid's unique identifier.*/
    public string $bidId;
    /** @var string $description The bid's description, set by the merchandiser on bid entry.*/
    public string $description;
    /** @var null|string $symbol The symbol for the bid's underlying futures contract.*/
    public ?string $symbol = null;
    /** @var null|string $clientGroupId An identifier that relates bids of different types.*/
    public ?string $clientGroupId = null;
    /** @var string $deliveryStart The first day of the bid's delivery month.*/
    public string $deliveryStart;
    /** @var string $deliveryEnd The last day of the bid's delivery month.*/
    public string $deliveryEnd;
    /** @var string $expirationDate The day on which the bid expires.*/
    public string $expirationDate;
    /** @var string $currentBid The bid's current price.*/
    public string $currentBid;
    /** @var null|string $basisPrice The bid's current basis.*/
    public ?string $basisPrice = null;
    /** @var string $unitOfMeasure The unit that the bid is measured in.*/
    public string $unitOfMeasure;
    /** @var null|string $currencyConversionRate The rate to convert the current bid to dollars.*/
    public ?string $currencyConversionRate = null;
    /** @var null|string $futuresPrice The bid's underlying futures price.*/
    public ?string $futuresPrice = null;
    /** @var null|string $futuresChange The bid's underlying futures change.*/
    public ?string $futuresChange = null;
    /** @var null|int $futuresChangeSign A flag denoting whether the bid's underlying futures change value is positive or negative.*/
    public ?int $futuresChangeSign = null;
    /** @var null|string $premiumPercent The premium added to the price by the merchandiser.*/
    public ?string $premiumPercent = null;
    /** @var null|string $unitConversionFactor The rate to convert the current bid's price at its current unit to the unit of the underlying future*/
    public ?string $unitConversionFactor = null;
    /** @var string $currency The underlying currency the bid is in.*/
    public string $currency;

    /**
     * @param  string  $locationName The centre name for the Location
     * @param  string  $commodityName The Commodity's name
     * @param  string  $productId The Product's id in the futures database.
     * @param  string  $productName The Product's name.
     * @param  string  $pricingType The Product's Type.
     * @param  string  $tickSize The Tick Size overwritten by the merchandiser.
     * @param  string  $marketTickSize The default Tick Size for the commodity.
     * @param  string  $bidId The bid's unique identifier.
     * @param  string  $description The bid's description, set by the merchandiser on bid entry.
     * @param  null|string  $symbol The symbol for the bid's underlying futures contract.
     * @param  null|string  $clientGroupId An identifier that relates bids of different types.
     * @param  string  $deliveryStart The first day of the bid's delivery month.
     * @param  string  $deliveryEnd The last day of the bid's delivery month.
     * @param  string  $expirationDate The day on which the bid expires.
     * @param  string  $currentBid The bid's current price.
     * @param  null|string  $basisPrice The bid's current basis.
     * @param  string  $unitOfMeasure The unit that the bid is measured in.
     * @param  null|string  $currencyConversionRate The rate to convert the current bid to dollars.
     * @param  null|string  $futuresPrice The bid's underlying futures price.
     * @param  null|string  $futuresChange The bid's underlying futures change.
     * @param  null|int  $futuresChangeSign A flag denoting whether the bid's underlying futures change value is positive or negative.
     * @param  null|string  $premiumPercent The premium added to the price by the merchandiser.
     * @param  null|string  $unitConversionFactor The rate to convert the current bid's price at its current unit to the unit of the underlying future
     * @param  string  $currency The underlying currency the bid is in.
     */
    public function __construct(string $locationName, string $commodityName, string $productId, string $productName, string $pricingType, string $tickSize, string $marketTickSize, string $bidId, string $description, ?string $symbol, ?string $clientGroupId, string $deliveryStart, string $deliveryEnd, string $expirationDate, string $currentBid, ?string $basisPrice, string $unitOfMeasure, ?string $currencyConversionRate, ?string $futuresPrice, ?string $futuresChange, ?int $futuresChangeSign, ?string $premiumPercent, ?string $unitConversionFactor, string $currency)
    {
        $this->locationName = $locationName;
        $this->commodityName = $commodityName;
        $this->productId = $productId;
        $this->productName = $productName;
        $this->pricingType = $pricingType;
        $this->tickSize = $tickSize;
        $this->marketTickSize = $marketTickSize;
        $this->bidId = $bidId;
        $this->description = $description;
        $this->symbol = $symbol;
        $this->clientGroupId = $clientGroupId;
        $this->deliveryStart = $deliveryStart;
        $this->deliveryEnd = $deliveryEnd;
        $this->expirationDate = $expirationDate;
        $this->currentBid = $currentBid;
        $this->basisPrice = $basisPrice;
        $this->unitOfMeasure = $unitOfMeasure;
        $this->currencyConversionRate = $currencyConversionRate;
        $this->futuresPrice = $futuresPrice;
        $this->futuresChange = $futuresChange;
        $this->futuresChangeSign = $futuresChangeSign;
        $this->premiumPercent = $premiumPercent;
        $this->unitConversionFactor = $unitConversionFactor;
        $this->currency = $currency;
    }
    

}